package com.portio.data

import android.net.Uri
import com.portio.utils.UUIDSerializer
import com.portio.utils.UriSerializer
import kotlinx.serialization.Serializable
import java.util.UUID

@Serializable
data class Plate(
    val name: String,
    val weight: Float,
    @Serializable(with = UUIDSerializer::class) val id: UUID = UUID.randomUUID(),
    @Serializable(with = UriSerializer::class) val imageUri: Uri? = null
) {
    fun isSimilarTo(other: Plate): Boolean {
        return name == other.name &&
                weight == other.weight &&
                imageUri == other.imageUri
    }

    fun isDefault(): Boolean = this.isSimilarTo(default())

    fun isValid(): Boolean = name.isNotBlank() && name.length <= MAX_LENGTH && imageUri != null

    companion object {
        fun default(): Plate = Plate("", 0f)
        const val MAX_LENGTH = 20
    }
}