package com.portio.data.repository

import android.content.Context
import android.graphics.Bitmap
import android.net.Uri
import android.util.Log
import com.portio.utils.UserAvatarUtils.processUserAvatar
import java.io.File

interface UserAvatarRepository {
    suspend fun fetchAndSaveUserImage(username: String): Uri?
    suspend fun deleteUserAvatar(username: String)
}

class LocalUserAvatarRepository(
    private val localDataSource: LocalUserAvatarDataSource
) : UserAvatarRepository {

    override suspend fun fetchAndSaveUserImage(username: String): Uri? {
        val outputBitmap = processUserAvatar(username) ?: return null
        return localDataSource.saveUserAvatar(username, outputBitmap)
    }

    override suspend fun deleteUserAvatar(username: String) {
        localDataSource.deleteUserAvatar(username)
    }
}

class LocalUserAvatarDataSource(private val context: Context) {

    fun saveUserAvatar(username: String, bitmap: Bitmap): Uri {
        val avatarFile = getAvatarFile(username)
        Log.i(TAG, "Saving file ${avatarFile.name}")

        avatarFile.outputStream().use { output ->
            bitmap.compress(Bitmap.CompressFormat.PNG, 90, output)
        }

        return Uri.fromFile(avatarFile)
    }

    fun deleteUserAvatar(username: String) {
        val fileToDelete = getAvatarFile(username)
        Log.i(TAG, "Deleting file ${fileToDelete.name}")
        fileToDelete.delete()
    }

    private fun getAvatarFile(username: String): File {
        val dir = File(context.filesDir, "UserAvatars")
        if (!dir.exists()) dir.mkdirs()
        return File(dir, "$username.png")
    }

    companion object {
        private val TAG = LocalUserAvatarDataSource::class.simpleName
    }
}