package com.portio.ui.screens.home

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.material3.TextButton
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.portio.R
import com.portio.utils.UnitLocale

@Preview(showBackground = true)
@Composable
fun WeightIndicatorPreview() {
    WeightIndicator(totalWeight = 350.0f)
}

@Composable
fun WeightIndicator(
    totalWeight: Float,
    modifier: Modifier = Modifier,
    onClick: () -> Unit = {}
) {
    Column(modifier = modifier) {
        Text(
            text = stringResource(R.string.total_weight),
            modifier = Modifier.fillMaxWidth(),
            textAlign = TextAlign.Center,
        )
        TextButton(onClick = onClick, modifier = Modifier.padding(top = 4.dp)) {
            Text(
                text = if (UnitLocale.default == UnitLocale.Metric)
                    stringResource(R.string.gram, totalWeight.toInt())
                else stringResource(R.string.ounce, totalWeight.toInt()),
                modifier = Modifier.fillMaxWidth(),
                textAlign = TextAlign.Center,
                style = MaterialTheme.typography.titleLarge.copy(
                    fontWeight = FontWeight.Bold,
                    fontSize = 38.sp
                )
            )
        }
    }
}