package com.portio.ui.sharedcomponents

import androidx.compose.foundation.Image
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.material3.surfaceColorAtElevation
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.alpha
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.ColorFilter
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import coil.compose.AsyncImage
import com.portio.R
import com.portio.data.Plate

@Preview
@Composable
fun PlatePreview() {
    val plate = Plate("Plate 1", 1.25f)
    PlateCard(Modifier, plate)
}

@Composable
fun PlateCardButton(modifier: Modifier, plate: Plate?, onClick: () -> Unit = {}) {
    Button(
        onClick = onClick,
        colors = ButtonDefaults.textButtonColors(),
        shape = MaterialTheme.shapes.medium,
        modifier = modifier,
        contentPadding = PaddingValues(all = 8.dp)
    ) {
        PlateCard(Modifier, plate)
    }
}

@Composable
fun PlateCard(modifier: Modifier, plate: Plate?) {
    Column(
        modifier = modifier,
    ) {
        Box(
            modifier = Modifier,
            contentAlignment = Alignment.Center
        ) {
            Image(
                painter = painterResource(id = R.drawable.plate_background),
                contentDescription = null,
                modifier = Modifier
                    .align(Alignment.Center)
                    .width(175.dp),
                contentScale = ContentScale.Crop,
                colorFilter = ColorFilter
                    .tint(MaterialTheme.colorScheme.surfaceColorAtElevation(1.dp))
            )

            if (plate != null) {
                if (plate.imageUri == null) {
                    Icon(
                        painter = painterResource(id = R.drawable.baseline_image_not_supported_24),
                        contentDescription = null,
                        modifier = Modifier
                            .align(Alignment.Center)
                            .size(75.dp)
                            .alpha(0.6f)
                    )
                } else {
                    AsyncImage(
                        model = plate.imageUri,
                        contentDescription = null,
                        modifier = Modifier
                            .align(Alignment.Center)
                            .size(150.dp)
                            .clip(MaterialTheme.shapes.medium),
                        contentScale = ContentScale.Crop
                    )
                }
            } else {
                Column(
                    verticalArrangement = Arrangement.Center,
                    horizontalAlignment = Alignment.CenterHorizontally
                ) {
                    Icon(
                        painter = painterResource(id = android.R.drawable.ic_input_add),
                        contentDescription = null,
                    )
                    Text(
                        modifier = Modifier.padding(8.dp),
                        textAlign = TextAlign.Center,
                        text = stringResource(R.string.add_first_plate),
                    )
                }
            }
        }
        Text(
            modifier = Modifier.align(Alignment.CenterHorizontally),
            text = plate?.name ?: "",
            style = MaterialTheme.typography.bodyMedium
        )
    }
}